@@ -18,9 +18,7 @@
  * USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "evolution-ews-config.h"
 
 #include <string.h>
 #include <errno.h>
@@ -1721,9 +1719,7 @@ e_ews_dump_file_attachment_from_soap_parameter (ESoapParameter *param,
 		param_name = e_soap_parameter_get_name (subparam);
 
 		if (g_ascii_strcasecmp (param_name, "Name") == 0) {
-			value = e_soap_parameter_get_string_value (subparam);
-			name = g_uri_escape_string (value, "", TRUE);
-			g_free (value);
+			name = e_soap_parameter_get_string_value (subparam);
 		} else if (g_ascii_strcasecmp (param_name, "Content") == 0) {
 			value = e_soap_parameter_get_string_value (subparam);
 			content = g_base64_decode (value, &data_len);
